@@ -420,7 +420,7 @@ def run_dvc_init():
         command = 'dvc_init.sh'
         if not isWindows:
             command = './' + command
-            os.chmod(command)
+            os.chmod(command, 444)
         subprocess.call(command, shell=True)
 
 def copy_deploy_files(main_dir):
